@@ -3,6 +3,7 @@ import re
 CLEAN_UP_PATTERNS = [
     ('\n', ''),
     ('-<br />', '<lb break="no"/>'),
+    ('-\u00a0<br />', '<lb break="no"/>'),
     ('<br />', '<lb />\n'),
     ('</p>', '<lb break="paragraph"/></p>\n'),
     ('-<lb break="paragraph"/></p>', '<lb break="no"/></p>'),
@@ -12,6 +13,10 @@ CLEAN_UP_PATTERNS = [
     ('</strong>', '</hi>'),
 ]
 
+POST_TEI_PROCESSING = [
+    ('\n', ''),
+]
+
 
 def clean_markup(source, patterns=CLEAN_UP_PATTERNS):
     """ applies search and replace
