@@ -24,6 +24,10 @@ FRD_MANIFESTATION = frd.FrdManifestation(
     auth_items=frd.AUTH_ITEMS,
     manifestation_id=MANIFESTATION_ID
 )
+FRD_INDEX = frd.FrdIndex(
+    auth_items=frd.AUTH_ITEMS,
+    out_dir="indices"
+)
 
 
 class TestFrdWerk(unittest.TestCase):
@@ -146,7 +150,7 @@ class TestFreud_api_crawler(unittest.TestCase):
     def test_014_check_tei_serialiazer(self):
         """test tei serialisation"""
         frd_obj = FRD_MANIFESTATION
-        xml = frd_obj.make_xml(dump=True)
+        xml = frd_obj.make_xml(dump=False)
         xml_str = ET.tostring(xml).decode('utf-8')
         print(type(xml), type(xml_str))
         self.assertTrue(frd_obj.manifestation_id in xml_str)
@@ -181,6 +185,14 @@ class TestFreud_api_crawler(unittest.TestCase):
         frd_obj_sub_field_id = item['data']['relationships']['vid']['data']['id']
         self.assertTrue(item2_id == frd_obj_sub_field_id)
 
+    def test_019_check_tei_serialiazer_index(self):
+        """test tei serialisation"""
+        frd_obj = FRD_INDEX
+        xml = frd_obj.make_index(save=False, dump=False, index_type='personen')
+        xml_str = ET.tostring(xml).decode('utf-8')
+        print(type(xml), type(xml_str))
+        self.assertTrue("p__7df674ca-0716-4c3f-88bc-c36d65b2db56" in xml_str)
+
 
 class TestStringUtils(unittest.TestCase):
     """Tests for `freud_api_crawler` package."""
